---
search:
  exclude: true
---
# コード例

[リポジトリ](https://github.com/openai/openai-agents-python/tree/main/examples) の examples セクションには、 SDK のさまざまなサンプル実装が用意されています。これらのコード例は、異なるパターンや機能を示す複数のカテゴリーに整理されています。


## カテゴリー

- **[agent_patterns](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns):**  
  このカテゴリーのコード例では、一般的なエージェント設計パターンを紹介しています。例:

    - 決定的ワークフロー
    - エージェントをツールとして利用
    - エージェントの並列実行

- **[basic](https://github.com/openai/openai-agents-python/tree/main/examples/basic):**  
  ここでは、以下のような SDK の基礎的な機能を紹介しています。例:

    - 動的なシステムプロンプト
    - ストリーミング出力
    - ライフサイクルイベント

- **[tool examples](https://github.com/openai/openai-agents-python/tree/main/examples/tools):**  
  Web 検索やファイル検索など、 OpenAI がホストするツールの実装方法と、それらをエージェントに統合する方法を学べます。

- **[model providers](https://github.com/openai/openai-agents-python/tree/main/examples/model_providers):**  
  OpenAI 以外のモデルを SDK と併用する方法を探求できます。

- **[handoffs](https://github.com/openai/openai-agents-python/tree/main/examples/handoffs):**  
  エージェントのハンドオフに関する実践的なコード例です。

- **[mcp](https://github.com/openai/openai-agents-python/tree/main/examples/mcp):**  
  MCP を用いたエージェントの構築方法を学べます。

- **[customer_service](https://github.com/openai/openai-agents-python/tree/main/examples/customer_service)** と **[research_bot](https://github.com/openai/openai-agents-python/tree/main/examples/research_bot):**  
  実際のユースケースを想定した、より充実した 2 つのコード例

    - **customer_service**: 航空会社向けのカスタマーサービスシステム例  
    - **research_bot**: シンプルなディープリサーチ クローン

- **[voice](https://github.com/openai/openai-agents-python/tree/main/examples/voice):**  
  TTS と STT モデルを利用した音声エージェントのコード例です。

- **[realtime](https://github.com/openai/openai-agents-python/tree/main/examples/realtime):**  
  SDK を用いてリアルタイム体験を構築する方法を示すコード例です。